@@ -26,3 +26,6 @@ class Voice(object):
 		"""Converts the dataclass obj to a dict using a shallow copy only."""
 		# We do not want the token variable to be return, token is internal
 		return dict((_field.name, getattr(self, _field.name)) for _field in fields(self) if _field.name != "token")
+
+	def __eq__(self, other) -> bool:
+		return self.id == other.id
